@@ -1,5 +1,5 @@
 ''' This module delivers basic etl file operations'''
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 import os
 from datetime import datetime
@@ -100,17 +100,17 @@ def get_empty_rows(file):
     return header, table, data
 
 
-def create_header_table(file, header):
-    """ Creates a dictionary bases on 2 header columns and transposes
+def create_header_table(filename, header_length, column_name_pos, data_pos):
+    """ Creates a dictionary bases on a 2 header columns and transposes
     it into a regular table with titles and content."""
 
     head_dict = {}
 
-    with xlrd.open_workbook(file) as workbook:
+    with xlrd.open_workbook(filename) as workbook:
         current_sheet = workbook.sheet_by_index(0)
 
-        for i in range(header):
-            head_dict[current_sheet.cell(i, 0).value] = [
-                current_sheet.cell(i, 1).value]
+        for i in range(header_length):
+            head_dict[current_sheet.cell(i, column_name_pos).value] = [
+                current_sheet.cell(i, data_pos).value]
 
     return pd.DataFrame.from_dict(head_dict)
